=================
Signal processing
=================


.. automodule:: elephant.signal_processing


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: sig
   :keyprefix: signal-
   :style: unsrt
